@@ -68,27 +68,31 @@ if os.path.exists(fn):
 		name = _name(re.split("/",ligne)[0])
 		if name in library:
 			ajout = _get(ligne)
-			# First lands because of some specific cards
+
 			if "Land" in ajout["types"]:
-				# Land first in case of Dryad Arbor
-				if "Creature" in ajout["types"] and "/" not in ligne:
-					# Dryad Arbor-like case
+				land["count"] = land["count"] + int(ajout["count"])
+
+				if len(ajout["types"]) == 1:
 					land["cards"].append(ajout)
-					land["count"] = land["count"] + int(ajout["count"]) # Increase land count
-				else:
-					# Usual land cards and artifact lands
-					land["cards"].append(ajout)
-					land["count"] = land["count"] + int(ajout["count"]) # Increase land count
+				elif "Creature" in ajout["types"]:
+					if "/" not in ligne:
+						crea["count"] = crea["count"] + int(ajout["count"])
+						land["cards"].append(ajout)
+						continue #: Will never add "Dryad Arbor" to Creatures
+				elif "Enchantment" in ajout["types"]:
+					if "/" not in ligne:
+						ench["count"] = ench["count"] + int(ajout["count"])
+						land["cards"].append(ajout)
+						continue #: Will never add Urza's Saga to Enchantments
+				elif "Artifact" in ajout["types"]:
+					if "/" not in ligne:
+						arti["count"] = arti["count"] + int(ajout["count"])
+						land["cards"].append(ajout)
+						continue #: Will never add Seat of the Synod to Artifacts
 
 			if "Creature" in ajout["types"]:
-				if "Land" not in ajout["types"]:
-					# usual case
-					crea["count"] = crea["count"] + int(ajout["count"])
-					crea["cards"].append(ajout)
-				if "Land" in ajout["types"] and "/" in ligne:
-					# MDFC creature-land case
-					crea["count"] = crea["count"] + int(ajout["count"])
-					crea["cards"].append(ajout)
+				crea["count"] = crea["count"] + int(ajout["count"])
+				crea["cards"].append(ajout)
 
 			elif "Planeswalker" in ajout["types"]:
 				plan["count"] = plan["count"] + int(ajout["count"])
